  #' @title aovDispMeans
#'
#' @description Displays marginal means from model.tables in the command window.
#'
#' @param ezObj Output from ezANOVA  (NB. ezANOVA must be called with \"return_aov = TRUE\"")
#' @param name Required for heading
#'
#' @return NULL
#'
#' @examples
#' library(psychReport)
#' requiredPackages(c("ez"))
#' # Example 1:
#' # create dataframe
#' dat <- createDF(nVP = 6,
#'                 nTrl = 1,
#'                 design = list("Comp" = c("comp", "incomp")))
#'
#' dat <- addDataDF(dat, RT = list(list(c("Comp:comp"), vals = c(500, 150, 100)),
#'                                 list(c("Comp:incomp"), vals = c(520, 150, 100))))
#'
#' aovRT <- ezANOVA(dat, dv=.(RT), wid = .(VP), within = .(Comp),
#'                  return_aov = TRUE, detailed = TRUE)
#' aovRT <- aovTable(aovRT)
#' aovDispMeans(aovRT)
#'
#' @export
aovDispMeans <- function(ezObj, name=sys.call()) {

  hasMeans <- ezObj$means
  if (is.null(hasMeans)) {
    stop("ezANOVA object does not contain marginal means!\nCall ezANOVA with \"return_aov = TRUE\"")
  } else {
    means = ezObj$means
  }

 for (i in 2:(length(means$n) + 1)) {
    heading <- paste0(c(row.names(as.data.frame(means$n)))[i - 1])
    dat <- reshape2::melt(means$tables[[i]][])
    width <- max(apply(dat, 1, function(x) sum(nchar(x))))
    ncols <- length(names(dat))
    if (i == 2) {
        name = paste0("Means:", unlist(lapply(name[2], as.character)))
        print(cli::rule(line = 2, center = crayon::black(name), width = width + ncols))
    }
    print(cli::rule(center = crayon::black(heading), width = width + ncols))
    print(dat, row.names = FALSE)
    cat("\n")
  }
  print(cli::rule(width = width + ncols))
}

